@@ -1,3 +1,5 @@
+import json
+
 from pydantic import BaseModel as PydanticBaseModel
 
 from pydantic.class_validators import root_validator
@@ -30,3 +32,6 @@ class BaseModel(PydanticBaseModel):
     def make_hashable_root(cls, values):
         # The root validator must take and return a dict
         return {k: make_hashable(v) for k, v in values.items()}
+
+    def to_dict(self) -> dict:
+        return json.loads(self.json())
