@@ -1,7 +1,10 @@
 """Shared models."""
+from __future__ import annotations
+
 import re
 from datetime import datetime
 from enum import Enum
+import string
 from typing import Any, Optional
 
 from pydantic import Field
@@ -10,15 +13,44 @@ from pydantic.types import ConstrainedStr
 from .base_model import BaseModel
 from .utils import HashableSequence
 
-
+# TODO: potential add validation for structure of CURIE
 class CURIE(str):
     """Compact URI."""
 
 
+class KnowledgeType(str, Enum):
+    "Knowledge Type."
+
+    lookup = "lookup"
+    inferred = "inferred"
+
+
 class EdgeIdentifier(str):
     """Identifier for an edge in a knowledge graph"""
 
 
+class RecursiveAttribute(BaseModel):
+    """Attribute subattribute."""
+
+    attribute_type_id: CURIE = Field(..., title="type")
+    value: Any = Field(..., title="value")
+    value_type_id: Optional[CURIE] = Field(
+        None,
+        title="value_type_id",
+        nullable=True,
+    )
+    original_attribute_name: Optional[str] = Field(None, nullable=True)
+    value_url: Optional[str] = Field(None, nullable=True)
+    attribute_source: Optional[str] = Field(None, nullable=True)
+    description: Optional[str] = Field(None, nullable=True)
+    attributes: Optional[HashableSequence[RecursiveAttribute]] = Field(
+        None, nullable=True
+    )
+
+    class Config:
+        extra = "forbid"
+
+
 class SubAttribute(BaseModel):
     """Attribute subattribute."""
 
@@ -33,6 +65,9 @@ class SubAttribute(BaseModel):
     value_url: Optional[str] = Field(None, nullable=True)
     attribute_source: Optional[str] = Field(None, nullable=True)
     description: Optional[str] = Field(None, nullable=True)
+    attributes: Optional[HashableSequence[RecursiveAttribute]] = Field(
+        None, nullable=True
+    )
 
     class Config:
         extra = "forbid"
@@ -58,6 +93,23 @@ class Attribute(BaseModel):
         extra = "forbid"
 
 
+class BiolinkQualifier(ConstrainedStr):
+    """Biolink Qualifier."""
+
+    regex = re.compile("^biolink:[a-z][a-z_]*$")
+
+    class Config:
+        title = "biolink entity"
+
+
+class Qualifier(BaseModel):
+    """Edge qualifier."""
+
+    qualifier_type_id: BiolinkQualifier = Field(..., title="type")
+
+    qualifier_value: str = Field(..., title="value")
+
+
 class BiolinkEntity(ConstrainedStr):
     """Biolink entity."""
 
@@ -101,3 +153,6 @@ class LogEntry(BaseModel):
 
     class Config:
         extra = "allow"
+
+
+RecursiveAttribute.update_forward_refs()
